@@ -1,6 +1,5 @@
 from __future__ import unicode_literals, division, absolute_import
 from datetime import timedelta, datetime
-import contextlib
 import logging
 
 from sqlalchemy import desc, func
@@ -35,31 +34,32 @@ class EstimatesReleasedSeries(object):
                     season = 1
                 log.debug("Querying release estimation for %s S%02dE%02d ..." %
                           (entry['series_name'], season, entry['series_episode']))
-                try:
-                    series_info = lookup_series(name=entry['series_name'])
-                except LookupError as e:
-                    log.debug('tvrage lookup error: %s' % e)
-                else:
-                    if series_info:
-                        try:
-                            episode_info = series_info.find_episode(season, entry['series_episode'])
-                            if episode_info:
-                                return episode_info.airdate
-                            else:
-                                # If episode does not exist in tvrage database, we always return a future date
-                                log.verbose('%s S%02dE%02d does not exist in tvrage database, assuming unreleased',
-                                          series_info.name, season, entry['series_episode'])
-                                return datetime.now() + timedelta(weeks=4)
-                        except Exception as e:
-                            log.exception(e)
+                with Session(expire_on_commit=False) as session:
+                    try:
+                        series_info = lookup_series(name=entry['series_name'], session=session)
+                    except LookupError as e:
+                        log.debug('tvrage lookup error: %s' % e)
                     else:
-                        log.debug('No series info obtained from TVRage to %s' % entry['series_name'])
+                        if series_info:
+                            try:
+                                episode_info = series_info.find_episode(season, entry['series_episode'])
+                                if episode_info:
+                                    return episode_info.airdate
+                                else:
+                                    # If episode does not exist in tvrage database, we always return a future date
+                                    log.verbose('%s S%02dE%02d does not exist in tvrage database, assuming unreleased',
+                                              series_info.name, season, entry['series_episode'])
+                                    return datetime.now() + timedelta(weeks=4)
+                            except Exception as e:
+                                log.exception(e)
+                        else:
+                            log.debug('No series info obtained from TVRage to %s' % entry['series_name'])
 
                 log.debug('No episode info obtained from TVRage for %s season %s episode %s' %
                           (entry['series_name'], entry['series_season'], entry['series_episode']))
 
             # If no results from tvrage, estimate a date based on series history
-            with contextlib.closing(Session()) as session:
+            with Session() as session:
                 series = session.query(Series).filter(Series.name == entry['series_name']).first()
                 if not series:
                     return
